@@ -14,7 +14,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from calculate.consolegui import qt
+from .. import qt
 
 class StatusLabel(qt.QLabel):
     def __init__(self, name, parent):
